@@ -1,18 +1,26 @@
 # -*- coding: utf-8 -*-
-# 
+#
 # Populate namespace with io routines
-# 
+#
 
 # Import __all__ routines from local modules
-from . import utils, load_raw_binary, load_spy_container, save_spy_container
+from . import (
+    utils,
+    load_spy_container,
+    save_spy_container,
+    load_ft,
+    _load_nwb
+)
 from .utils import *
-from .load_raw_binary import *
 from .load_spy_container import *
 from .save_spy_container import *
+from .load_ft import *
+from ._load_nwb import *
 
 # Populate local __all__ namespace
 __all__ = []
 __all__.extend(utils.__all__)
-__all__.extend(load_raw_binary.__all__)
 __all__.extend(load_spy_container.__all__)
 __all__.extend(save_spy_container.__all__)
+__all__.extend(load_ft.__all__)
+__all__.extend(_load_nwb.__all__)
