@@ -20,10 +20,10 @@ spectralConversions = {"pow": lambda x: (x * np.conj(x)).real.astype(np.float32)
 
 #: available tapers of :func:`~syncopy.freqanalysis` and  :func:`~syncopy.connectivity`
 all_windows = windows.__all__
-all_windows.remove("exponential") # not symmetric
-all_windows.remove("hanning") # deprecated
-all_windows.remove("gaussian") # we don't support taper with args
-all_windows.remove("kaiser") # we don't support taper with args
+all_windows.remove("get_window")  # aux. function
+all_windows.remove("exponential")  # not symmetric
+all_windows.remove("hanning")  # deprecated
+all_windows.remove("dpss")  # activated via `tapsmofrq`
 
 availableTapers = all_windows
 availablePaddingOpt = [None, 'nextpow2']
