@@ -452,16 +452,6 @@ class TestBaseData():
                     operation(dummy, np.inf)
                     assert "'inf'; expected finite scalar" in str(spyval.value)
 
-                # Complex scalar (all test data are real)
-                with pytest.raises(SPYTypeError) as spytyp:
-                    operation(dummy, complexNum)
-                    assert "expected scalar of same mathematical type (real/complex)" in str(spytyp.value)
-
-                # Array w/wrong numeric type
-                with pytest.raises(SPYTypeError) as spytyp:
-                    operation(dummy, complexArr)
-                    assert "array of same numerical type (real/complex) found ndarray" in str(spytyp.value)
-
                 # Syncopy object of different type
                 with pytest.raises(SPYTypeError) as spytyp:
                     operation(dummy, other)
