@@ -7,18 +7,20 @@
 import psutil
 import pytest
 import inspect
-import itertools
 import numpy as np
 import matplotlib.pyplot as ppl
 
 # Local imports
+
 from syncopy import __acme__
 if __acme__:
     import dask.distributed as dd
-from syncopy.datatype import AnalogData
-from syncopy.connectivity import connectivity
+
+from syncopy import AnalogData
+from syncopy import connectivityanalysis as cafunc
 import syncopy.tests.synth_data as synth_data
-from syncopy.shared.errors import SPYValueError, SPYTypeError
+import syncopy.tests.helpers as helpers
+from syncopy.shared.errors import SPYValueError
 from syncopy.shared.tools import get_defaults
 
 # Decorator to decide whether or not to run dask-related tests
@@ -65,8 +67,10 @@ class TestGranger:
 
     def test_gr_solution(self, **kwargs):
 
-        Gcaus = connectivity(self.data, method='granger', taper='dpss',
-                             tapsmofrq=3, foi=self.foi, **kwargs)
+
+        Gcaus = cafunc(self.data, method='granger',
+                       tapsmofrq=3, foi=None, **kwargs)
+
 
         # check all channel combinations with coupling
         for i, j in zip(*self.cpl_idx):
@@ -90,13 +94,13 @@ class TestGranger:
     def test_gr_selections(self):
 
         # trial, channel and toi selections
-        selections = mk_selection_dicts(self.nTrials,
-                                        self.nChannels,
-                                        *self.time_span)
+        selections = helpers.mk_selection_dicts(self.nTrials,
+                                                self.nChannels,
+                                                *self.time_span)
 
         for sel_dct in selections:
 
-            Gcaus = connectivity(self.data, method='granger', select=sel_dct)
+            Gcaus = cafunc(self.data, method='granger', select=sel_dct)
 
             # check here just for finiteness and positivity
             assert np.all(np.isfinite(Gcaus.data))
@@ -104,17 +108,27 @@ class TestGranger:
 
     def test_gr_foi(self):
 
-        call = lambda foi, foilim: connectivity(self.data,
-                                                method='granger',
-                                                foi=foi,
-                                                foilim=foilim)
+        try:
+            cafunc(self.data,
+                   method='granger',
+                   foi=np.arange(0, 70)
+                   )
+        except SPYValueError as err:
+            assert 'no foi specification' in str(err)
 
-        run_foi_test(call, foilim=[0, 70])
+        try:
+            cafunc(self.data,
+                   method='granger',
+                   foilim=[0, 70]
+                   )
+        except SPYValueError as err:
+            assert 'no foi specification' in str(err)
 
     def test_gr_cfg(self):
 
-        call = lambda cfg: connectivity(self.data, cfg)
-        run_cfg_test(call, method='granger')
+        call = lambda cfg: cafunc(self.data, cfg)
+        run_cfg_test(call, method='granger',
+                     cfg=get_defaults(cafunc))
 
     @skip_without_acme
     @skip_low_mem
@@ -135,7 +149,7 @@ class TestGranger:
 
         pad_length = int(1.7 * self.nSamples)
         call = lambda pad_to_length: self.test_gr_solution(pad_to_length=pad_to_length)
-        run_padding_test(call, pad_length)
+        helpers.run_padding_test(call, pad_length)
 
     def test_gr_polyremoval(self):
 
@@ -143,11 +157,12 @@ class TestGranger:
         self.data = self.data + 10
 
         call = lambda polyremoval: self.test_gr_solution(polyremoval=polyremoval)
-        run_polyremoval_test(call)
+        helpers.run_polyremoval_test(call)
 
         # remove the constant again
         self.data = self.data - 10
 
+
 class TestCoherence:
 
     nSamples = 1500
@@ -161,9 +176,9 @@ class TestCoherence:
     trls = []
     for _ in range(nTrials):
         # a lot of phase diffusion (1% per step) in the 20Hz band
-        p1 = synth_data.phase_evo(f1, eps=.01, nChannels=nChannels, nSamples=nSamples)
+        p1 = synth_data.phase_diffusion(f1, eps=.01, nChannels=nChannels, nSamples=nSamples)
         # little diffusion in the 40Hz band
-        p2 = synth_data.phase_evo(f2, eps=0.001, nChannels=nChannels, nSamples=nSamples)
+        p2 = synth_data.phase_diffusion(f2, eps=0.001, nChannels=nChannels, nSamples=nSamples)
         # superposition
         signals = np.cos(p1) + np.cos(p2)
         # noise stabilizes the result(!!)
@@ -175,13 +190,12 @@ class TestCoherence:
 
     def test_coh_solution(self, **kwargs):
 
-        res = connectivity(data=self.data,
-                           method='coh',
-                           foilim=[5, 60],
-                           output='pow',
-                           taper='dpss',
-                           tapsmofrq=1.5,
-                           **kwargs)
+        res = cafunc(data=self.data,
+                     method='coh',
+                     foilim=[5, 60],
+                     output='pow',
+                     tapsmofrq=1.5,
+                     **kwargs)
 
         # coherence at the harmonic frequencies
         idx_f1 = np.argmin(res.freq < self.f1)
@@ -199,17 +213,19 @@ class TestCoherence:
         # is low coherence
         null_idx = (res.freq < self.f1 - 5) | (res.freq > self.f1 + 5)
         null_idx *= (res.freq < self.f2 - 5) | (res.freq > self.f2 + 5)
-        assert np.all(res.data[0, null_idx, 0, 1] < 0.1)
+        assert np.all(res.data[0, null_idx, 0, 1] < 0.15)
+
+        plot_coh(res, 0, 1, label="channel 0-1")
 
     def test_coh_selections(self):
 
-        selections = mk_selection_dicts(self.nTrials,
-                                        self.nChannels,
-                                        *self.time_span)
+        selections = helpers.mk_selection_dicts(self.nTrials,
+                                                self.nChannels,
+                                                *self.time_span)
 
         for sel_dct in selections:
 
-            result = connectivity(self.data, method='coh', select=sel_dct)
+            result = cafunc(self.data, method='coh', select=sel_dct)
 
             # check here just for finiteness and positivity
             assert np.all(np.isfinite(result.data))
@@ -217,17 +233,18 @@ class TestCoherence:
 
     def test_coh_foi(self):
 
-        call = lambda foi, foilim: connectivity(self.data,
-                                                method='coh',
-                                                foi=foi,
-                                                foilim=foilim)
+        call = lambda foi, foilim: cafunc(self.data,
+                                          method='coh',
+                                          foi=foi,
+                                          foilim=foilim)
 
-        run_foi_test(call, foilim=[0, 70])
+        helpers.run_foi_test(call, foilim=[0, 70])
 
     def test_coh_cfg(self):
 
-        call = lambda cfg: connectivity(self.data, cfg)
-        run_cfg_test(call, method='coh')
+        call = lambda cfg: cafunc(self.data, cfg)
+        run_cfg_test(call, method='coh',
+                     cfg=get_defaults(cafunc))
 
     @skip_without_acme
     @skip_low_mem
@@ -248,12 +265,12 @@ class TestCoherence:
 
         pad_length = int(1.2 * self.nSamples)
         call = lambda pad_to_length: self.test_coh_solution(pad_to_length=pad_to_length)
-        run_padding_test(call, pad_length)
+        helpers.run_padding_test(call, pad_length)
 
     def test_coh_polyremoval(self):
 
         call = lambda polyremoval: self.test_coh_solution(polyremoval=polyremoval)
-        run_polyremoval_test(call)
+        helpers.run_polyremoval_test(call)
 
 
 class TestCorrelation:
@@ -270,9 +287,9 @@ class TestCorrelation:
     for _ in range(nTrials):
 
         # no phase diffusion
-        p1 = synth_data.phase_evo(f1, eps=0, nChannels=nChannels, nSamples=nSamples)
+        p1 = synth_data.phase_diffusion(f1, eps=0, nChannels=nChannels, nSamples=nSamples)
         # same frequency but more diffusion
-        p2 = synth_data.phase_evo(f1, eps=0.1, nChannels=1, nSamples=nSamples)
+        p2 = synth_data.phase_diffusion(f1, eps=0.1, nChannels=1, nSamples=nSamples)
         # set 2nd channel to higher phase diffusion
         p1[:, 1] = p2[:, 0]
         # add a pi/2 phase shift for the even channels
@@ -285,7 +302,7 @@ class TestCorrelation:
 
     def test_corr_solution(self, **kwargs):
 
-        corr = connectivity(data=self.data, method='corr', **kwargs)
+        corr = cafunc(data=self.data, method='corr', **kwargs)
 
         # test 0-lag autocorr is 1 for all channels
         assert np.all(corr.data[0, 0].diagonal() > .99)
@@ -360,21 +377,23 @@ class TestCorrelation:
 
     def test_corr_selections(self):
 
-        selections = mk_selection_dicts(self.nTrials,
-                                       self.nChannels,
-                                       *self.time_span)
+        selections = helpers.mk_selection_dicts(self.nTrials,
+                                                self.nChannels,
+                                                *self.time_span)
 
         for sel_dct in selections:
 
-            result = connectivity(self.data, method='corr', select=sel_dct)
+            result = cafunc(self.data, method='corr', select=sel_dct)
 
             # check here just for finiteness and positivity
             assert np.all(np.isfinite(result.data))
 
     def test_corr_cfg(self):
 
-        call = lambda cfg: connectivity(self.data, cfg)
-        run_cfg_test(call, method='corr', positivity=False)
+        call = lambda cfg: cafunc(self.data, cfg)
+        run_cfg_test(call, method='corr',
+                     positivity=False,
+                     cfg=get_defaults(cafunc))
 
     @skip_without_acme
     @skip_low_mem
@@ -394,79 +413,22 @@ class TestCorrelation:
     def test_corr_polyremoval(self):
 
         call = lambda polyremoval: self.test_corr_solution(polyremoval=polyremoval)
-        run_polyremoval_test(call)
-
-# -- helper functions --
+        helpers.run_polyremoval_test(call)
 
 
-def run_padding_test(call, pad_length):
-    """
-    The callable should test a solution and support
-    a single keyword argument `pad_to_length`
-    """
-
-    pad_options = [pad_length, 'nextpow2', None]
-    for pad in pad_options:
-        call(pad_to_length=pad)
-
-    # test invalid pads
-    try:
-        call(pad_to_length=2)
-    except SPYValueError as err:
-        assert 'pad_to_length' in str(err)
-        assert 'expected value to be greater' in str(err)
-
-    try:
-        call(pad_to_length='IamNoPad')
-    except SPYValueError as err:
-        assert 'Invalid value of `pad_to_length`' in str(err)
-        assert 'nextpow2' in str(err)
-
-    try:
-        call(pad_to_length=np.array([1000]))
-    except SPYValueError as err:
-        assert 'Invalid value of `pad_to_length`' in str(err)
-        assert 'nextpow2' in str(err)
-
-
-def run_polyremoval_test(call):
-    """
-    The callable should test a solution and support
-    a single keyword argument `polyremoval`
-    """
-
-    poly_options = [0, 1]
-    for poly in poly_options:
-        call(polyremoval=poly)
-
-    # test invalid polyremoval options
-    try:
-        call(polyremoval=2)
-    except SPYValueError as err:
-        assert 'polyremoval' in str(err)
-        assert 'expected value to be greater' in str(err)
-
-    try:
-        call(polyremoval='IamNoPad')
-    except SPYTypeError as err:
-        assert 'Wrong type of `polyremoval`' in str(err)
-
-    try:
-        call(polyremoval=np.array([1000]))
-    except SPYTypeError as err:
-        assert 'Wrong type of `polyremoval`' in str(err)
-
-
-def run_cfg_test(call, method, positivity=True):
-
-    cfg = get_defaults(connectivity)
+def run_cfg_test(method_call, method, cfg, positivity=True):
 
     cfg.method = method
-    cfg.foilim = [0, 70]
-    cfg.taper = 'parzen'
+    if method != 'granger':
+        cfg.foilim = [0, 70]
+    # test general tapers with
+    # additional parameters
+    cfg.taper = 'kaiser'
+    cfg.taper_opt = {'beta': 2}
+
     cfg.output = 'abs'
 
-    result = call(cfg)
+    result = method_call(cfg)
 
     # check here just for finiteness and positivity
     assert np.all(np.isfinite(result.data))
@@ -474,130 +436,6 @@ def run_cfg_test(call, method, positivity=True):
         assert np.all(result.data[0, ...] >= -1e-10)
 
 
-def run_foi_test(call, foilim, positivity=True):
-
-    # only positive frequencies
-    assert np.min(foilim) >= 0
-    assert np.max(foilim) <= 500
-
-    # fois
-    foi1 = np.arange(foilim[0], foilim[1]) # 1Hz steps
-    foi2 = np.arange(foilim[0], foilim[1], 0.25) # 0.5Hz steps
-    foi3 = 'all'
-    fois = [foi1, foi2, foi3, None]
-
-    for foi in fois:
-        # FIXME: this works for method='granger' but not method='coh' 0.0
-
-        result = call(foi=foi, foilim=None)
-        # check here just for finiteness and positivity
-        assert np.all(np.isfinite(result.data))
-        if positivity:
-            assert np.all(result.data[0, ...] >= -1e-10)
-
-    # 2 foilims
-    foilims = [[2, 60], [7.65, 45.1234], None]
-    for foil in foilims:
-        result = call(foilim=foil, foi=None)
-        # check here just for finiteness and positivity
-        assert np.all(np.isfinite(result.data))
-        if positivity:
-            assert np.all(result.data[0, ...] >= -1e-10)
-
-    # make sure specification of both foi and foilim triggers a
-    # Syncopy ValueError
-    try:
-        result = call(foi=foi, foilim=foil)
-    except SPYValueError as err:
-        assert 'foi/foilim' in str(err)
-
-    # make sure out-of-range foi selections are detected
-    try:
-        result = call(foilim=[-1, 70], foi=None)
-    except SPYValueError as err:
-        assert 'foilim' in str(err)
-        assert 'bounded by' in str(err)
-
-    try:
-        result = call(foi=np.arange(550, 700), foilim=None)
-    except SPYValueError as err:
-        assert 'foi' in str(err)
-        assert 'bounded by' in str(err)
-
-
-def mk_selection_dicts(nTrials, nChannels, toi_min, toi_max):
-
-    # at least 10 trials
-    assert nTrials > 9
-    # at least 2 channels
-    assert nChannels > 1
-    # at least 250ms
-    assert (toi_max - toi_min) > 0.25
-
-    # create 3 random trial and channel selections
-    trials, channels = [], []
-    for _ in range(3):
-
-        sizeTr = np.random.randint(10, nTrials + 1)
-        trials.append(list(np.random.choice(
-            nTrials, size=sizeTr
-        )
-        ))
-
-        sizeCh = np.random.randint(2, nChannels + 1)
-        channels.append(['channel' + str(i + 1)
-                         for i in
-                         np.random.choice(
-                             nChannels, size=sizeCh, replace=False
-                         )])
-
-    # create toi selections, signal length is toi_max
-    # with -1s as offset (from synthetic data instantiation)
-    # subsampling does NOT WORK due to precision issues :/
-    # toi1 = np.linspace(-.4, 2, 100)
-    tois = [None, 'all']
-    toi_combinations = itertools.product(trials,
-                                         channels,
-                                         tois)
-
-    # 2 random toilims
-    toilims = []
-    while len(toilims) < 2:
-
-        toil = np.sort(np.random.rand(2)) * (toi_max - toi_min) + toi_min
-        # at least 250ms
-        if np.diff(toil) < 0.25:
-            continue
-        else:
-            toilims.append(toil)
-
-    # combinatorics of all selection options
-    # order matters to assign the selection dict keys!
-    toilim_combinations = itertools.product(trials,
-                                            channels,
-                                            toilims)
-
-    selections = []
-    # digest generators to create all selection dictionaries
-    for comb in toi_combinations:
-
-        sel_dct = {}
-        sel_dct['trials'] = comb[0]
-        sel_dct['channels'] = comb[1]
-        sel_dct['toi'] = comb[2]
-        selections.append(sel_dct)
-
-    for comb in toilim_combinations:
-
-        sel_dct = {}
-        sel_dct['trials'] = comb[0]
-        sel_dct['channels'] = comb[1]
-        sel_dct['toilim'] = comb[2]
-        selections.append(sel_dct)
-
-    return selections
-
-
 def plot_Granger(G, i, j):
 
     ax = ppl.gca()
@@ -614,6 +452,7 @@ def plot_coh(res, i, j, label=''):
     ax.set_xlabel('frequency (Hz)')
     ax.set_ylabel('coherence $|CSD|^2$')
     ax.plot(res.freq, res.data[0, :, i, j], label=label)
+    ax.legend()
 
 
 def plot_corr(res, i, j, label=''):
@@ -622,6 +461,7 @@ def plot_corr(res, i, j, label=''):
     ax.set_xlabel('lag (s)')
     ax.set_ylabel('Correlation')
     ax.plot(res.time[0], res.data[:, 0, i, j], label=label)
+    ax.legend()
 
 
 if __name__ == '__main__':
