@@ -8,6 +8,8 @@ import os
 import tempfile
 import time
 import pytest
+import random
+import numbers
 import numpy as np
 from numpy.lib.format import open_memmap
 
@@ -41,13 +43,15 @@ trialSelections = [
 ]
 chanSelections = [
     ["channel03", "channel01", "channel01", "channel02"],  # string selection w/repetition + unordered
-    [4, 2, 2, 5, 5],   # repetition + unorderd
+    [4, 2, 2, 5, 5],   # repetition + unordered
     range(5, 8),  # narrow range
-    slice(-2, None)  # negative-start slice
+    slice(-2, None),  # negative-start slice
+    "channel02", # str selection
+    1  # scalar selection
     ]
 toiSelections = [
     "all",  # non-type-conform string
-    [0.6],  # single inexact match
+    0.6,  # single inexact match
     [-0.2, 0.6, 0.9, 1.1, 1.3, 1.6, 1.8, 2.2, 2.45, 3.]  # unordered, inexact, repetions
     ]
 toilimSelections = [
@@ -57,7 +61,7 @@ toilimSelections = [
     ]
 foiSelections = [
     "all",  # non-type-conform string
-    [2.6],  # single inexact match
+    2.6,  # single inexact match
     [1.1, 1.9, 2.1, 3.9, 9.2, 11.8, 12.9, 5.1, 13.8]  # unordered, inexact, repetions
     ]
 foilimSelections = [
@@ -67,6 +71,8 @@ foilimSelections = [
     ]
 taperSelections = [
     ["TestTaper_03", "TestTaper_01", "TestTaper_01", "TestTaper_02"],  # string selection w/repetition + unordered
+    "TestTaper_03",  # singe str
+    0,  # scalar selection
     [0, 1, 1, 2, 3],  # preserve repetition, don't convert to slice
     range(2, 5),  # narrow range
     slice(0, 5, 2),  # slice w/non-unitary step-size
@@ -76,7 +82,6 @@ timeSelections = list(zip(["toi"] * len(toiSelections), toiSelections)) \
 freqSelections = list(zip(["foi"] * len(foiSelections), foiSelections)) \
     + list(zip(["foilim"] * len(foilimSelections), foilimSelections))
 
-
 # Local helper function for performing basic arithmetic tests
 def _base_op_tests(dummy, ymmud, dummy2, ymmud2, dummyC, operation):
 
@@ -87,11 +92,11 @@ def _base_op_tests(dummy, ymmud, dummy2, ymmud2, dummyC, operation):
     ymmudOperands = [ymmudArr, ymmudArr.tolist()]
 
     # Ensure trial counts are properly vetted
-    dummy2.selectdata(trials=[0], inplace=True)
+    dummy2.selectdata(trials=0, inplace=True)
     with pytest.raises(SPYValueError) as spyval:
         operation(dummy, dummy2)
         assert "Syncopy object with same number of trials (selected)" in str (spyval.value)
-    dummy2._selection = None
+    dummy2.selection = None
 
     # Scalar algebra must be commutative (except for pow)
     for operand in scalarOperands:
@@ -174,10 +179,10 @@ def _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation):
                                                 selected.trials[tk]))
 
     # Very important: clear manually set selections for next iteration
-    dummy._selection = None
-    dummy2._selection = None
-    ymmud._selection = None
-    ymmud2._selection = None
+    dummy.selection = None
+    dummy2.selection = None
+    ymmud.selection = None
+    ymmud2.selection = None
 
 
 class TestAnalogData():
@@ -490,7 +495,7 @@ class TestAnalogData():
 
         # real thing: pad object with standing channel selection
         res = padding(adata, "zero", pad="absolute", padlength=total_time,unit="time",
-                      create_new=True, select={"trials": trialSel, "channels": chanSel})
+                      create_new=True, select={"trials": trialSel, "channel": chanSel})
         for tk, trl in enumerate(res.trials):
             adataTrl = adata.trials[trialSel[tk]]
             nSamples = pad_list[trialSel[tk]]["pad_width"][timeAxis, :].sum() + adataTrl.shape[timeAxis]
@@ -529,7 +534,7 @@ class TestAnalogData():
 
         # same as above, but this time w/swapped dimensions
         res2 = padding(adata2, "zero", pad="absolute", padlength=total_time, unit="time",
-                       create_new=True, select={"trials": trialSel, "channels": chanSel})
+                       create_new=True, select={"trials": trialSel, "channel": chanSel})
         pad_list2 = padding(adata2, "zero", pad="absolute", padlength=total_time,
                             unit="time", create_new=False)
         for tk, trl in enumerate(res2.trials):
@@ -567,7 +572,7 @@ class TestAnalogData():
                                           equidistant=False, overlapping=True,
                                           inmemory=False, dimord=adata2.dimord)
         res3 = padding(adata3, "zero", pad="absolute", padlength=total_time, unit="time",
-                       create_new=True, select={"trials": trialSel, "channels": chanSel})
+                       create_new=True, select={"trials": trialSel, "channel": chanSel})
         pad_list3 = padding(adata3, "zero", pad="absolute", padlength=total_time,
                             unit="time", create_new=False)
         for tk, trl in enumerate(res3.trials):
@@ -586,7 +591,7 @@ class TestAnalogData():
                     create_new=False)
 
     # test data-selection via class method
-    def test_dataselection(self):
+    def test_dataselection(self, fulltests):
 
         # Create testing objects (regular and swapped dimords)
         dummy = AnalogData(data=self.data,
@@ -597,21 +602,31 @@ class TestAnalogData():
                            samplerate=self.samplerate,
                            dimord=AnalogData._defaultDimord[::-1])
 
+        # Randomly pick one selection unless tests are run with `--full`
+        if fulltests:
+            trialSels = trialSelections
+            chanSels = chanSelections
+            timeSels = timeSelections
+        else:
+            trialSels = [random.choice(trialSelections)]
+            chanSels = [random.choice(chanSelections)]
+            timeSels = [random.choice(timeSelections)]
+
         for obj in [dummy, ymmud]:
             idx = [slice(None)] * len(obj.dimord)
             timeIdx = obj.dimord.index("time")
             chanIdx = obj.dimord.index("channel")
-            for trialSel in trialSelections:
-                for chanSel in chanSelections:
-                    for timeSel in timeSelections:
+            for trialSel in trialSels:
+                for chanSel in chanSels:
+                    for timeSel in timeSels:
                         kwdict = {}
                         kwdict["trials"] = trialSel
-                        kwdict["channels"] = chanSel
+                        kwdict["channel"] = chanSel
                         kwdict[timeSel[0]] = timeSel[1]
                         cfg = StructDict(kwdict)
                         # data selection via class-method + `Selector` instance for indexing
                         selected = obj.selectdata(**kwdict)
-                        time.sleep(0.05)
+                        time.sleep(0.001)
                         selector = Selector(obj, kwdict)
                         idx[chanIdx] = selector.channel
                         for tk, trialno in enumerate(selector.trials):
@@ -624,10 +639,10 @@ class TestAnalogData():
                         selectdata(cfg)
                         assert np.array_equal(cfg.out.channel, selected.channel)
                         assert np.array_equal(cfg.out.data, selected.data)
-                        time.sleep(0.05)
+                        time.sleep(0.001)
 
     # test arithmetic operations
-    def test_ang_arithmetic(self):
+    def test_ang_arithmetic(self, fulltests):
 
         # Create testing objects and corresponding arrays to perform arithmetics with
         dummy = AnalogData(data=self.data,
@@ -655,22 +670,25 @@ class TestAnalogData():
 
             _base_op_tests(dummy, ymmud, dummy2, ymmud2, None, operation)
 
-            # Now the most complicated case: user-defined subset selections are present
-            kwdict = {}
-            kwdict["trials"] = trialSelections[1]
-            kwdict["channels"] = chanSelections[3]
-            kwdict[timeSelections[4][0]] = timeSelections[4][1]
-            _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
-
-            # # Go through full selection stack - WARNING: this takes > 15 minutes
-            # for trialSel in trialSelections:
-            #     for chanSel in chanSelections:
-            #         for timeSel in timeSelections:
-            #             kwdict = {}
-            #             kwdict["trials"] = trialSel
-            #             kwdict["channels"] = chanSel
-            #             kwdict[timeSel[0]] = timeSel[1]
-            #             _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
+            # Go through full selection stack - WARNING: this takes > 15 minutes
+            if fulltests:
+                for trialSel in trialSelections:
+                    for chanSel in chanSelections:
+                        for timeSel in timeSelections:
+                            kwdict = {}
+                            kwdict["trials"] = trialSel
+                            kwdict["channel"] = chanSel
+                            kwdict[timeSel[0]] = timeSel[1]
+                            ScalarSelectors = [isinstance(val, (numbers.Number, str)) for val in kwdict.values()]
+                            if sum(ScalarSelectors) >= 2:
+                                continue
+                            _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
+            else:
+                kwdict = {}
+                kwdict["trials"] = trialSelections[1]
+                kwdict["channel"] = chanSelections[3]
+                kwdict[timeSelections[4][0]] = timeSelections[4][1]
+                _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
 
         # Finally, perform a representative chained operation to ensure chaining works
         result = (dummy + dummy2) / dummy ** 3
@@ -679,17 +697,20 @@ class TestAnalogData():
                                   (dummy.trials[tk] + dummy2.trials[tk]) / dummy.trials[tk] ** 3)
 
     @skip_without_acme
-    def test_parallel(self, testcluster):
+    def test_parallel(self, testcluster, fulltests):
         # repeat selected test w/parallel processing engine
         client = dd.Client(testcluster)
-        par_tests = ["test_relative_array_padding",
-                     "test_absolute_nextpow2_array_padding",
-                     "test_object_padding",
-                     "test_dataselection",
-                     "test_ang_arithmetic"]
-        for test in par_tests:
+        quick_tests = ["test_relative_array_padding",
+                       "test_absolute_nextpow2_array_padding",
+                       "test_object_padding"]
+        slow_tests = ["test_dataselection",
+                      "test_ang_arithmetic"]
+        for test in quick_tests:
             getattr(self, test)()
             flush_local_cluster(testcluster)
+        for test in slow_tests:
+            getattr(self, test)(fulltests)
+            flush_local_cluster(testcluster)
         client.close()
 
 
@@ -795,7 +816,7 @@ class TestSpectralData():
             del dummy, dummy2
 
     # test data-selection via class method
-    def test_sd_dataselection(self):
+    def test_sd_dataselection(self, fulltests):
 
         # Create testing objects (regular and swapped dimords)
         dummy = SpectralData(data=self.data,
@@ -808,27 +829,41 @@ class TestSpectralData():
                              taper=["TestTaper_0{}".format(k) for k in range(1, self.nt + 1)],
                              dimord=SpectralData._defaultDimord[::-1])
 
+        # Randomly pick one selection unless tests are run with `--full`
+        if fulltests:
+            trialSels = trialSelections
+            chanSels = chanSelections
+            timeSels = timeSelections
+            freqSels = freqSelections
+            taperSels = taperSelections
+        else:
+            trialSels = [random.choice(trialSelections)]
+            chanSels = [random.choice(chanSelections)]
+            timeSels = [random.choice(timeSelections)]
+            freqSels = [random.choice(freqSelections)]
+            taperSels = [random.choice(taperSelections)]
+
         for obj in [dummy, ymmud]:
             idx = [slice(None)] * len(obj.dimord)
             timeIdx = obj.dimord.index("time")
             chanIdx = obj.dimord.index("channel")
             freqIdx = obj.dimord.index("freq")
             taperIdx = obj.dimord.index("taper")
-            for trialSel in trialSelections:
-                for chanSel in chanSelections:
-                    for timeSel in timeSelections:
-                        for freqSel in freqSelections:
-                            for taperSel in taperSelections:
+            for trialSel in trialSels:
+                for chanSel in chanSels:
+                    for timeSel in timeSels:
+                        for freqSel in freqSels:
+                            for taperSel in taperSels:
                                 kwdict = {}
                                 kwdict["trials"] = trialSel
-                                kwdict["channels"] = chanSel
+                                kwdict["channel"] = chanSel
                                 kwdict[timeSel[0]] = timeSel[1]
                                 kwdict[freqSel[0]] = freqSel[1]
-                                kwdict["tapers"] = taperSel
+                                kwdict["taper"] = taperSel
                                 cfg = StructDict(kwdict)
                                 # data selection via class-method + `Selector` instance for indexing
                                 selected = obj.selectdata(**kwdict)
-                                time.sleep(0.05)
+                                time.sleep(0.001)
                                 selector = Selector(obj, kwdict)
                                 idx[chanIdx] = selector.channel
                                 idx[freqIdx] = selector.freq
@@ -846,10 +881,10 @@ class TestSpectralData():
                                 assert np.array_equal(cfg.out.freq, selected.freq)
                                 assert np.array_equal(cfg.out.taper, selected.taper)
                                 assert np.array_equal(cfg.out.data, selected.data)
-                                time.sleep(0.05)
+                                time.sleep(0.001)
 
     # test arithmetic operations
-    def test_sd_arithmetic(self):
+    def test_sd_arithmetic(self, fulltests):
 
         # Create testing objects and corresponding arrays to perform arithmetics with
         dummy = SpectralData(data=self.data,
@@ -885,28 +920,32 @@ class TestSpectralData():
 
             _base_op_tests(dummy, ymmud, dummy2, ymmud2, dummyC, operation)
 
-            # Now the most complicated case: user-defined subset selections are present
-            kwdict = {}
-            kwdict["trials"] = trialSelections[1]
-            kwdict["channels"] = chanSelections[3]
-            kwdict[timeSelections[4][0]] = timeSelections[4][1]
-            kwdict[freqSelections[4][0]] = freqSelections[4][1]
-            kwdict["tapers"] = taperSelections[2]
-            _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
+            # Go through full selection stack - WARNING: this takes > 1 hour
+            if fulltests:
+                for trialSel in trialSelections:
+                    for chanSel in chanSelections:
+                        for timeSel in timeSelections:
+                            for freqSel in freqSelections:
+                                for taperSel in taperSelections:
+                                    kwdict = {}
+                                    kwdict["trials"] = trialSel
+                                    kwdict["channel"] = chanSel
+                                    kwdict[timeSel[0]] = timeSel[1]
+                                    kwdict[freqSel[0]] = freqSel[1]
+                                    kwdict["taper"] = taperSel
+                                    ScalarSelectors = [isinstance(val, (numbers.Number, str)) for val in kwdict.values()]
+                                    if sum(ScalarSelectors) >= 2:
+                                        continue
+                                    _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
+            else:
+                kwdict = {}
+                kwdict["trials"] = trialSelections[1]
+                kwdict["channel"] = chanSelections[3]
+                kwdict[timeSelections[4][0]] = timeSelections[4][1]
+                kwdict[freqSelections[4][0]] = freqSelections[4][1]
+                kwdict["taper"] = taperSelections[2]
+                _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
 
-            # # Go through full selection stack - WARNING: this takes > 1 hour
-            # for trialSel in trialSelections:
-            #     for chanSel in chanSelections:
-            #         for timeSel in timeSelections:
-            #             for freqSel in freqSelections:
-            #                 for taperSel in taperSelections:
-            #                     kwdict = {}
-            #                     kwdict["trials"] = trialSel
-            #                     kwdict["channels"] = chanSel
-            #                     kwdict[timeSel[0]] = timeSel[1]
-            #                     kwdict[freqSel[0]] = freqSel[1]
-            #                     kwdict["tapers"] = taperSel
-            #                     _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
 
         # Finally, perform a representative chained operation to ensure chaining works
         result = (dummy + dummy2) / dummy ** 3
@@ -915,12 +954,12 @@ class TestSpectralData():
                                   (dummy.trials[tk] + dummy2.trials[tk]) / dummy.trials[tk] ** 3)
 
     @skip_without_acme
-    def test_sd_parallel(self, testcluster):
+    def test_sd_parallel(self, testcluster, fulltests):
         # repeat selected test w/parallel processing engine
         client = dd.Client(testcluster)
         par_tests = ["test_sd_dataselection", "test_sd_arithmetic"]
         for test in par_tests:
-            getattr(self, test)()
+            getattr(self, test)(fulltests)
             flush_local_cluster(testcluster)
         client.close()
 
@@ -1029,7 +1068,7 @@ class TestCrossSpectralData():
             del dummy, dummy2
 
     # test data-selection via class method
-    def test_csd_dataselection(self):
+    def test_csd_dataselection(self, fulltests):
 
         # Create testing objects (regular and swapped dimords)
         dummy = CrossSpectralData(data=self.data,
@@ -1040,36 +1079,50 @@ class TestCrossSpectralData():
                                   dimord=CrossSpectralData._defaultDimord[::-1])
         ymmud.trialdefinition = self.trl
 
+        # Randomly pick one selection unless tests are run with `--full`
+        if fulltests:
+            trialSels = trialSelections
+            chanSels = chanSelections[2:]
+            timeSels = timeSelections
+            freqSels = freqSelections
+        else:
+            trialSels = [random.choice(trialSelections)]
+            chanSels = [random.choice(chanSelections[2:])]
+            timeSels = [random.choice(timeSelections)]
+            freqSels = [random.choice(freqSelections)]
+
         for obj in [dummy, ymmud]:
             idx = [slice(None)] * len(obj.dimord)
             timeIdx = obj.dimord.index("time")
             chanIdx = obj.dimord.index("channel_i")
             chanJdx = obj.dimord.index("channel_j")
             freqIdx = obj.dimord.index("freq")
-            for trialSel in trialSelections:
-                for chaniSel in chanSelections:
-                    for chanjSel in chanSelections:
-                        for timeSel in timeSelections:
-                            for freqSel in freqSelections:
+            for trialSel in trialSels:
+                for chaniSel in chanSels:
+                    for chanjSel in chanSels:
+                        for timeSel in timeSels:
+                            for freqSel in freqSels:
                                 kwdict = {}
                                 kwdict["trials"] = trialSel
-                                kwdict["channels_i"] = chaniSel
-                                kwdict["channels_j"] = chanjSel
+                                kwdict["channel_i"] = chaniSel
+                                kwdict["channel_j"] = chanjSel
                                 kwdict[timeSel[0]] = timeSel[1]
                                 kwdict[freqSel[0]] = freqSel[1]
                                 cfg = StructDict(kwdict)
                                 # data selection via class-method + `Selector` instance for indexing
                                 selected = obj.selectdata(**kwdict)
-                                time.sleep(0.05)
+                                time.sleep(0.001)
                                 selector = Selector(obj, kwdict)
                                 idx[chanIdx] = selector.channel_i
                                 idx[chanJdx] = selector.channel_j
                                 idx[freqIdx] = selector.freq
+                                jdx = [[elem] if np.issubdtype(type(elem), np.number) else elem for elem in idx]
+                                idx = jdx
                                 for tk, trialno in enumerate(selector.trials):
                                     idx[timeIdx] = selector.time[tk]
                                     indexed = obj.trials[trialno][idx[0], ...][:, idx[1], ...][:, :, idx[2], :][..., idx[3]]
                                     assert np.array_equal(selected.trials[tk].squeeze(),
-                                                        indexed.squeeze())
+                                                          indexed.squeeze())
                                 cfg.data = obj
                                 cfg.out = CrossSpectralData(dimord=obj.dimord)
                                 # data selection via package function and `cfg`: ensure equality
@@ -1078,10 +1131,10 @@ class TestCrossSpectralData():
                                 assert np.array_equal(cfg.out.channel_j, selected.channel_j)
                                 assert np.array_equal(cfg.out.freq, selected.freq)
                                 assert np.array_equal(cfg.out.data, selected.data)
-                                time.sleep(0.05)
+                                time.sleep(0.001)
 
     # test arithmetic operations
-    def test_csd_arithmetic(self):
+    def test_csd_arithmetic(self, fulltests):
 
         # Create testing objects and corresponding arrays to perform arithmetics with
         dummy = CrossSpectralData(data=self.data,
@@ -1112,14 +1165,28 @@ class TestCrossSpectralData():
 
             _base_op_tests(dummy, ymmud, dummy2, ymmud2, dummyC, operation)
 
-            # Now the most complicated case: user-defined subset selections are present
-            kwdict = {}
-            kwdict["trials"] = trialSelections[1]
-            kwdict["channels_i"] = chanSelections[3]
-            kwdict["channels_j"] = chanSelections[2]
-            kwdict[timeSelections[4][0]] = timeSelections[4][1]
-            kwdict[freqSelections[4][0]] = freqSelections[4][1]
-            _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
+            # Go through full selection stack - WARNING: this takes > 1 hour
+            if fulltests:
+                for trialSel in trialSelections:
+                    for chaniSel in chanSelections[2:]:
+                        for chanjSel in chanSelections[2:]:
+                            for timeSel in timeSelections:
+                                for freqSel in freqSelections:
+                                    kwdict = {}
+                                    kwdict["trials"] = trialSel
+                                    kwdict["channel_i"] = chaniSel
+                                    kwdict["channel_j"] = chanjSel
+                                    kwdict[timeSel[0]] = timeSel[1]
+                                    kwdict[freqSel[0]] = freqSel[1]
+                                    _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
+            else:
+                kwdict = {}
+                kwdict["trials"] = trialSelections[1]
+                kwdict["channel_i"] = chanSelections[3]
+                kwdict["channel_j"] = chanSelections[4]
+                kwdict[timeSelections[4][0]] = timeSelections[4][1]
+                kwdict[freqSelections[4][0]] = freqSelections[4][1]
+                _selection_op_tests(dummy, ymmud, dummy2, ymmud2, kwdict, operation)
 
         # Finally, perform a representative chained operation to ensure chaining works
         result = (dummy + dummy2) / dummy ** 3
@@ -1128,11 +1195,11 @@ class TestCrossSpectralData():
                                   (dummy.trials[tk] + dummy2.trials[tk]) / dummy.trials[tk] ** 3)
 
     @skip_without_acme
-    def test_csd_parallel(self, testcluster):
+    def test_csd_parallel(self, testcluster, fulltests):
         # repeat selected test w/parallel processing engine
         client = dd.Client(testcluster)
         par_tests = ["test_csd_dataselection", "test_csd_arithmetic"]
         for test in par_tests:
-            getattr(self, test)()
+            getattr(self, test)(fulltests)
             flush_local_cluster(testcluster)
         client.close()
