@@ -7,6 +7,7 @@
 import os
 import tempfile
 import inspect
+import random
 import psutil
 import gc
 import pytest
@@ -19,7 +20,7 @@ if __acme__:
 
 # Local imports
 from syncopy.tests.misc import generate_artificial_data, flush_local_cluster
-from syncopy.specest.freqanalysis import freqanalysis
+from syncopy import freqanalysis
 from syncopy.shared.errors import SPYValueError
 from syncopy.datatype.base_data import VirtualData, Selector
 from syncopy.datatype import AnalogData, SpectralData
@@ -126,9 +127,9 @@ class TestMTMFFT():
     # Data selections to be tested w/data generated based on `sig`
     sigdataSelections = [None,
                          {"trials": [3, 1, 0],
-                          "channels": ["channel" + str(i) for i in range(12, 28)][::-1]},
+                          "channel": ["channel" + str(i) for i in range(12, 28)][::-1]},
                          {"trials": [0, 1, 2],
-                          "channels": range(0, int(nChannels / 2)),
+                          "channel": range(0, int(nChannels / 2)),
                           "toilim": [0.25, 0.75]}]
 
     # Data selections to be tested w/`artdata` generated below (use fixed but arbitrary
@@ -136,10 +137,10 @@ class TestMTMFFT():
     seed = np.random.RandomState(13)
     artdataSelections = [None,
                          {"trials": [3, 1, 0],
-                          "channels": ["channel" + str(i) for i in range(10, 15)][::-1],
+                          "channel": ["channel" + str(i) for i in range(10, 15)][::-1],
                           "toi": None},
                          {"trials": [0, 1, 2],
-                          "channels": range(0, 8),
+                          "channel": range(0, 8),
                           "toilim": [-0.5, 0.6]}]
 
     # Error tolerances for target amplitudes (depend on data selection!)
@@ -148,6 +149,12 @@ class TestMTMFFT():
     # Error tolerance for frequency-matching
     ftol = 0.25
 
+    # Helper function that reduces dataselections (keep `None` selection no matter what)
+    def test_cut_selections(self, fulltests):
+        if not fulltests:
+            self.sigdataSelections.pop(random.choice([-1, 1]))
+            self.artdataSelections.pop(random.choice([-1, 1]))
+
     def test_output(self):
         # ensure that output type specification is respected
         for select in self.sigdataSelections:
@@ -189,7 +196,7 @@ class TestMTMFFT():
 
         # keep trials but throw away tapers
         out = SpectralData(dimord=SpectralData._defaultDimord)
-        freqanalysis(self.adata, method="mtmfft", taper="dpss",
+        freqanalysis(self.adata, method="mtmfft",
                      tapsmofrq=3, keeptapers=False, output="pow", out=out)
         assert out.sampleinfo.shape == (self.nTrials, 2)
         assert out.taper.size == 1
@@ -197,7 +204,6 @@ class TestMTMFFT():
         # re-use `cfg` from above and additionally throw away `tapers`
         cfg.dataset = self.adata
         cfg.out = SpectralData(dimord=SpectralData._defaultDimord)
-        cfg.taper = "dpss"
         cfg.tapsmofrq = 3
         cfg.output = "pow"
         cfg.keeptapers = False
@@ -258,12 +264,12 @@ class TestMTMFFT():
 
             # ensure default setting results in single taper
             spec = freqanalysis(self.adata, method="mtmfft",
-                                taper="dpss", tapsmofrq=3,  output="pow", select=select)
+                                tapsmofrq=3, output="pow", select=select)
             assert spec.taper.size == 1
             assert spec.channel.size == len(chanList)
 
             # specify tapers
-            spec = freqanalysis(self.adata, method="mtmfft", taper="dpss",
+            spec = freqanalysis(self.adata, method="mtmfft",
                                 tapsmofrq=7, keeptapers=True, select=select)
             assert spec.channel.size == len(chanList)
 
@@ -273,7 +279,6 @@ class TestMTMFFT():
         timeAxis = artdata.dimord.index("time")
         cfg = StructDict()
         cfg.method = "mtmfft"
-        cfg.taper = "dpss"
         cfg.tapsmofrq = 9.3
         cfg.output = "pow"
 
@@ -374,7 +379,7 @@ class TestMTMFFT():
             vdata = VirtualData([dmap, dmap])
             avdata = AnalogData(vdata, samplerate=self.fs,
                                 trialdefinition=self.trialdefinition)
-            spec = freqanalysis(avdata, method="mtmfft", taper="dpss",
+            spec = freqanalysis(avdata, method="mtmfft",
                                 tapsmofrq=3, keeptapers=False, output="abs", pad="relative",
                                 padlength=npad)
             assert (np.diff(avdata.sampleinfo)[0][0] + npad) / 2 + 1 == spec.freq.size
@@ -388,7 +393,7 @@ class TestMTMFFT():
         # (skip VirtualData tests since ``wrapper_io`` expects valid headers)
         client = dd.Client(testcluster)
         all_tests = [attr for attr in self.__dir__()
-                     if (inspect.ismethod(getattr(self, attr)) and attr != "test_parallel")]
+                     if (inspect.ismethod(getattr(self, attr)) and attr not in ["test_parallel", "test_cut_selections"])]
         all_tests.remove("test_vdata")
         for test in all_tests:
             getattr(self, test)()
@@ -397,7 +402,6 @@ class TestMTMFFT():
         # now create uniform `cfg` for remaining SLURM tests
         cfg = StructDict()
         cfg.method = "mtmfft"
-        cfg.taper = "dpss"
         cfg.tapsmofrq = 9.3
         cfg.output = "pow"
 
@@ -479,31 +483,38 @@ class TestMTMConvol():
     # Data selection dict for the above object
     dataSelections = [None,
                       {"trials": [1, 2, 0],
-                       "channels": ["channel" + str(i) for i in range(2, 6)][::-1]},
+                       "channel": ["channel" + str(i) for i in range(2, 6)][::-1]},
                       {"trials": [0, 2],
-                       "channels": range(0, nChan2),
+                       "channel": range(0, nChan2),
                        "toilim": [-20, 60.8]}]
 
-    def test_tf_output(self):
+    # Helper function that reduces dataselections (keep `None` selection no matter what)
+    def test_tf_cut_selections(self, fulltests):
+        if not fulltests:
+            self.dataSelections.pop(random.choice([-1, 1]))
+
+    def test_tf_output(self, fulltests):
         # Set up basic TF analysis parameters to not slow down things too much
         cfg = get_defaults(freqanalysis)
         cfg.method = "mtmconvol"
         cfg.taper = "hann"
         cfg.toi = np.linspace(-20, 60, 10)
         cfg.t_ftimwin = 1.0
+        outputDict = {"fourier" : "complex", "abs" : "float", "pow" : "float"}
 
         for select in self.dataSelections:
-            select = self.dataSelections[-1]
-            cfg.select = select
-            cfg.output = "fourier"
-            tfSpec = freqanalysis(cfg, self.tfData)
-            assert "complex" in tfSpec.data.dtype.name
-            cfg.output = "abs"
-            tfSpec = freqanalysis(cfg, self.tfData)
-            assert "float" in tfSpec.data.dtype.name
-            cfg.output = "pow"
-            tfSpec = freqanalysis(cfg, self.tfData)
-            assert "float" in tfSpec.data.dtype.name
+            if fulltests:
+                cfg.select = select
+                for key, value in outputDict.items():
+                    cfg.output = key
+                    tfSpec = freqanalysis(cfg, self.tfData)
+                    assert value in tfSpec.data.dtype.name
+            else: # randomly pick from 'fourier', 'abs' and 'pow' and work w/smaller signal
+                cfg.select = {"trials" : 0, "channel" : 1}
+                cfg.output = random.choice(list(outputDict.keys()))
+                cfg.toi = np.linspace(-20, 60, 5)
+                tfSpec = freqanalysis(cfg, _make_tf_signal(2, 2, self.seed, fadeIn=self.fadeIn, fadeOut=self.fadeOut)[0])
+                assert outputDict[cfg.output] in tfSpec.data.dtype.name
 
     def test_tf_allocout(self):
         # use `mtmconvol` w/pre-allocated output object
@@ -535,7 +546,7 @@ class TestMTMConvol():
 
         # keep trials but throw away tapers
         out = SpectralData(dimord=SpectralData._defaultDimord)
-        freqanalysis(self.tfData, method="mtmconvol", taper="dpss", tapsmofrq=3,
+        freqanalysis(self.tfData, method="mtmconvol", tapsmofrq=3,
                      keeptapers=False, output="pow", toi=0.0, t_ftimwin=1.0,
                      out=out)
         assert out.sampleinfo.shape == (self.nTrials, 2)
@@ -544,7 +555,6 @@ class TestMTMConvol():
         # re-use `cfg` from above and additionally throw away `tapers`
         cfg.dataset = self.tfData
         cfg.out = SpectralData(dimord=SpectralData._defaultDimord)
-        cfg.taper = "dpss"
         cfg.tapsmofrq = 3
         cfg.keeptapers = False
         cfg.output = "pow"
@@ -612,7 +622,7 @@ class TestMTMConvol():
                     chanNo = chan
                     if select:
                         if "toilim" not in select.keys():
-                            chanNo = np.where(self.tfData.channel == select["channels"][chan])[0][0]
+                            chanNo = np.where(self.tfData.channel == select["channel"][chan])[0][0]
                     if chanNo % 2:
                         modIdx = self.odd[(-1)**trlNo]
                     else:
@@ -696,10 +706,9 @@ class TestMTMConvol():
 
         # Test correct time-array assembly for ``toi = "all"`` (cut down data signifcantly
         # to not overflow memory here); same for ``toi = 1.0```
-        cfg.taper = "dpss"
         cfg.tapsmofrq = 10
         cfg.keeptapers = True
-        cfg.select = {"trials": [0], "channels": [0], "toilim": [-0.5, 0.5]}
+        cfg.select = {"trials": [0], "channel": [0], "toilim": [-0.5, 0.5]}
         cfg.toi = "all"
         cfg.t_ftimwin = 0.05
         tfSpec = freqanalysis(cfg, self.tfData)
@@ -731,21 +740,28 @@ class TestMTMConvol():
             freqanalysis(cfg, self.tfData)
             assert "Invalid value of `toi`: 'unsorted list/array'" in str(spyval.value)
 
-    def test_tf_irregular_trials(self):
+    def test_tf_irregular_trials(self, fulltests):
         # Settings for computing "full" non-overlapping TF-spectrum with DPSS tapers:
         # ensure non-equidistant/overlapping trials are processed (padded) correctly
         # also make sure ``toi = "all"`` works under any circumstance
         cfg = get_defaults(freqanalysis)
         cfg.method = "mtmconvol"
-        cfg.taper = "dpss"
         cfg.tapsmofrq = 10
         cfg.t_ftimwin = 1.0
         cfg.output = "pow"
         cfg.keeptapers = True
 
+        # Reduce test-data size for quick test runs
+        if fulltests:
+            nTrials = 5
+            nChannels = 8
+        else:
+            nTrials = 2
+            nChannels = 2
+
         # start harmless: equidistant trials w/multiple tapers
         cfg.toi = 0.0
-        artdata = generate_artificial_data(nTrials=5, nChannels=16,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            equidistant=True, inmemory=False)
         tfSpec = freqanalysis(artdata, **cfg)
         assert tfSpec.taper.size >= 1
@@ -754,7 +770,7 @@ class TestMTMConvol():
 
         # to process all time-points via `stft`, reduce dataset size (avoid oom kills)
         cfg.toi = "all"
-        artdata = generate_artificial_data(nTrials=5, nChannels=4,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            equidistant=True, inmemory=False)
         tfSpec = freqanalysis(artdata, **cfg)
         for tk, origTime in enumerate(artdata.time):
@@ -762,7 +778,7 @@ class TestMTMConvol():
 
         # non-equidistant trials w/multiple tapers
         cfg.toi = 0.0
-        artdata = generate_artificial_data(nTrials=5, nChannels=8,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            equidistant=False, inmemory=False)
         tfSpec = freqanalysis(artdata, **cfg)
         assert tfSpec.taper.size >= 1
@@ -775,7 +791,7 @@ class TestMTMConvol():
 
         # same + reversed dimensional order in input object
         cfg.toi = 0.0
-        cfg.data = generate_artificial_data(nTrials=5, nChannels=8,
+        cfg.data = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                             equidistant=False, inmemory=False,
                                             dimord=AnalogData._defaultDimord[::-1])
         tfSpec = freqanalysis(cfg)
@@ -789,7 +805,7 @@ class TestMTMConvol():
 
         # same + overlapping trials
         cfg.toi = 0.0
-        cfg.data = generate_artificial_data(nTrials=5, nChannels=4,
+        cfg.data = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                             equidistant=False, inmemory=False,
                                             dimord=AnalogData._defaultDimord[::-1],
                                             overlapping=True)
@@ -804,14 +820,20 @@ class TestMTMConvol():
 
     @skip_without_acme
     @skip_low_mem
-    def test_tf_parallel(self, testcluster):
+    def test_tf_parallel(self, testcluster, fulltests):
         # collect all tests of current class and repeat them running concurrently
         client = dd.Client(testcluster)
-        all_tests = [attr for attr in self.__dir__()
-                     if (inspect.ismethod(getattr(self, attr)) and attr != "test_tf_parallel")]
-        for test in all_tests:
+        quick_tests = [attr for attr in self.__dir__()
+                       if (inspect.ismethod(getattr(self, attr)) and attr not in ["test_tf_parallel", "test_tf_cut_selections"])]
+        slow_tests = []
+        slow_tests.append(quick_tests.pop(quick_tests.index("test_tf_output")))
+        slow_tests.append(quick_tests.pop(quick_tests.index("test_tf_irregular_trials")))
+        for test in quick_tests:
             getattr(self, test)()
             flush_local_cluster(testcluster)
+        for test in slow_tests:
+            getattr(self, test)(fulltests)
+            flush_local_cluster(testcluster)
 
         # now create uniform `cfg` for remaining SLURM tests
         cfg = StructDict()
@@ -821,14 +843,22 @@ class TestMTMConvol():
         cfg.toi = 0
         cfg.output = "pow"
 
+        # reduce test dataset size unless we're in `--full` mode
+        if fulltests:
+            nChannels = self.nChannels
+            nTrials = self.nTrials
+        else:
+            nChannels = 3
+            nTrials = 2
+
         # no. of HDF5 files that will make up virtual data-set in case of channel-chunking
         chanPerWrkr = 2
-        nFiles = self.nTrials * (int(self.nChannels/chanPerWrkr)
-                                 + int(self.nChannels % chanPerWrkr > 0))
+        nFiles = nTrials * (int(nChannels/chanPerWrkr)
+                            + int(nChannels % chanPerWrkr > 0))
 
         # simplest case: equidistant trial spacing, all in memory
-        fileCount = [self.nTrials, nFiles]
-        artdata = generate_artificial_data(nTrials=self.nTrials, nChannels=self.nChannels,
+        fileCount = [nTrials, nFiles]
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            inmemory=True)
         for k, chan_per_worker in enumerate([None, chanPerWrkr]):
             cfg.chan_per_worker = chan_per_worker
@@ -838,7 +868,7 @@ class TestMTMConvol():
 
         # non-equidistant trial spacing
         cfg.keeptapers = False
-        artdata = generate_artificial_data(nTrials=self.nTrials, nChannels=self.nChannels,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            inmemory=True, equidistant=False)
         expectedFreqs = np.arange(artdata.samplerate / 2 + 1)
         for chan_per_worker in enumerate([None, chanPerWrkr]):
@@ -848,10 +878,9 @@ class TestMTMConvol():
 
         # equidistant trial spacing, keep tapers
         cfg.output = "abs"
-        cfg.taper = "dpss"
         cfg.tapsmofrq = 10
         cfg.keeptapers = True
-        artdata = generate_artificial_data(nTrials=self.nTrials, nChannels=self.nChannels,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            inmemory=False)
         for chan_per_worker in enumerate([None, chanPerWrkr]):
             tfSpec = freqanalysis(artdata, cfg)
@@ -861,7 +890,7 @@ class TestMTMConvol():
         cfg.keeptapers = False
         cfg.keeptrials = "no"
         cfg.output = "pow"
-        artdata = generate_artificial_data(nTrials=self.nTrials, nChannels=self.nChannels,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            inmemory=False, equidistant=True,
                                            overlapping=True)
         expectedFreqs = np.arange(artdata.samplerate / 2 + 1)
@@ -869,7 +898,7 @@ class TestMTMConvol():
         assert np.array_equal(tfSpec.freq, expectedFreqs)
         assert tfSpec.taper.size == 1
         assert np.array_equal(np.unique(np.floor(artdata.time[0])), tfSpec.time[0])
-        assert tfSpec.data.shape == (tfSpec.time[0].size, 1, expectedFreqs.size, self.nChannels)
+        assert tfSpec.data.shape == (tfSpec.time[0].size, 1, expectedFreqs.size, nChannels)
 
         client.close()
 
@@ -889,11 +918,16 @@ class TestWavelet():
     # Set up in-place data-selection dicts for the constructed object
     dataSelections = [None,
                       {"trials": [1, 2, 0],
-                       "channels": ["channel" + str(i) for i in range(2, 4)][::-1]},
+                       "channel": ["channel" + str(i) for i in range(2, 4)][::-1]},
                       {"trials": [0, 2],
-                       "channels": range(0, int(nChannels / 2)),
+                       "channel": range(0, int(nChannels / 2)),
                        "toilim": [-20, 60.8]}]
 
+    # Helper function that reduces dataselections (keep `None` selection no matter what)
+    def test_wav_cut_selections(self, fulltests):
+        if not fulltests:
+            self.dataSelections.pop(random.choice([-1, 1]))
+
     @skip_low_mem
     def test_wav_solution(self):
 
@@ -965,7 +999,7 @@ class TestWavelet():
                     chanNo = chan
                     if select:
                         if "toilim" not in select.keys():
-                            chanNo = np.where(self.tfData.channel == select["channels"][chan])[0][0]
+                            chanNo = np.where(self.tfData.channel == select["channel"][chan])[0][0]
                     if chanNo % 2:
                         modIdx = self.odd[(-1)**trlNo]
                     else:
@@ -1034,7 +1068,7 @@ class TestWavelet():
 
         # Test correct time-array assembly for ``toi = "all"`` (cut down data signifcantly
         # to not overflow memory here)
-        cfg.select = {"trials": [0], "channels": [0], "toilim": [-0.5, 0.5]}
+        cfg.select = {"trials": [0], "channel": [0], "toilim": [-0.5, 0.5]}
         cfg.toi = "all"
         tfSpec = freqanalysis(cfg, self.tfData)
         dt = 1/self.tfData.samplerate
@@ -1095,11 +1129,11 @@ class TestWavelet():
 
     @skip_without_acme
     @skip_low_mem
-    def test_wav_parallel(self, testcluster):
+    def test_wav_parallel(self, testcluster, fulltests):
         # collect all tests of current class and repeat them running concurrently
         client = dd.Client(testcluster)
         all_tests = [attr for attr in self.__dir__()
-                     if (inspect.ismethod(getattr(self, attr)) and attr != "test_wav_parallel")]
+                     if (inspect.ismethod(getattr(self, attr)) and attr not in ["test_wav_parallel", "test_wav_cut_selections"])]
         for test in all_tests:
             getattr(self, test)()
             flush_local_cluster(testcluster)
@@ -1111,14 +1145,21 @@ class TestWavelet():
         cfg.output = "pow"
         cfg.toi = "all"
 
+        # reduce test dataset size unless we're in `--full` mode
+        if fulltests:
+            nChannels = self.nChannels
+            nTrials = self.nTrials
+        else:
+            nChannels = 3
+            nTrials = 2
+
         # no. of HDF5 files that will make up virtual data-set in case of channel-chunking
         chanPerWrkr = 2
-        nFiles = self.nTrials * (int(self.nChannels/chanPerWrkr)
-                                 + int(self.nChannels % chanPerWrkr > 0))
+        nFiles = nTrials * (int(nChannels/chanPerWrkr) + int(nChannels % chanPerWrkr > 0))
 
         # simplest case: equidistant trial spacing, all in memory
-        fileCount = [self.nTrials, nFiles]
-        artdata = generate_artificial_data(nTrials=self.nTrials, nChannels=self.nChannels,
+        fileCount = [nTrials, nFiles]
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            inmemory=True)
         for k, chan_per_worker in enumerate([None, chanPerWrkr]):
             cfg.chan_per_worker = chan_per_worker
@@ -1128,7 +1169,7 @@ class TestWavelet():
 
         # non-equidistant trial spacing
         cfg.keeptapers = False
-        artdata = generate_artificial_data(nTrials=self.nTrials, nChannels=self.nChannels,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            inmemory=True, equidistant=False)
         for chan_per_worker in enumerate([None, chanPerWrkr]):
             tfSpec = freqanalysis(artdata, cfg)
@@ -1137,7 +1178,7 @@ class TestWavelet():
 
         # equidistant trial spacing
         cfg.output = "abs"
-        artdata = generate_artificial_data(nTrials=self.nTrials, nChannels=self.nChannels,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            inmemory=False)
         for chan_per_worker in enumerate([None, chanPerWrkr]):
             tfSpec = freqanalysis(artdata, cfg)
@@ -1148,12 +1189,12 @@ class TestWavelet():
         cfg.keeptrials = "no"
         cfg.foilim = [1, 250]
         expectedFreqs = np.arange(1, cfg.foilim[1] + 1)
-        artdata = generate_artificial_data(nTrials=self.nTrials, nChannels=self.nChannels,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            inmemory=False, equidistant=True,
                                            overlapping=True)
         tfSpec = freqanalysis(artdata, cfg)
         assert np.allclose(tfSpec.freq, expectedFreqs)
-        assert tfSpec.data.shape == (tfSpec.time[0].size, 1, expectedFreqs.size, self.nChannels)
+        assert tfSpec.data.shape == (tfSpec.time[0].size, 1, expectedFreqs.size, nChannels)
 
         client.close()
 
@@ -1173,13 +1214,18 @@ class TestSuperlet():
     # Set up in-place data-selection dicts for the constructed object
     dataSelections = [None,
                       {"trials": [1, 2, 0],
-                       "channels": ["channel" + str(i) for i in range(2, 4)][::-1]},
+                       "channel": ["channel" + str(i) for i in range(2, 4)][::-1]},
                       {"trials": [0, 2],
-                       "channels": range(0, int(nChannels / 2)),
+                       "channel": range(0, int(nChannels / 2)),
                        "toilim": [-20, 60.8]}]
 
+    # Helper function that reduces dataselections (keep `None` selection no matter what)
+    def test_slet_cut_selections(self, fulltests):
+        if not fulltests:
+            self.dataSelections.pop(random.choice([-1, 1]))
+
     @skip_low_mem
-    def test_slet_solution(self):
+    def test_slet_solution(self, fulltests):
 
         # Compute TF specturm across entire time-interval (use integer-valued
         # time-points as wavelet centroids)
@@ -1215,22 +1261,21 @@ class TestSuperlet():
 
             # Compute TF objects w\w/o`foi`/`foilim`
             cfg.select = select
-            tfSpec = freqanalysis(cfg, self.tfData)
             cfg.foi = maxFreqs
             tfSpecFoi = freqanalysis(cfg, self.tfData)
             cfg.foi = None
+            assert np.allclose(tfSpecFoi.freq, maxFreqs)
             cfg.foilim = [maxFreqs.min(), maxFreqs.max()]
             tfSpecFoiLim = freqanalysis(cfg, self.tfData)
             cfg.foilim = None
-
-            # Ensure TF objects contain expected/requested frequencies
-            assert 0.02 > tfSpec.freq.min() > 0
-            assert tfSpec.freq.max() == (self.tfData.samplerate / 2)
-            assert tfSpec.freq.size > 60
-            assert np.allclose(tfSpecFoi.freq, maxFreqs)
             assert np.allclose(tfSpecFoiLim.freq, foilimFreqs)
+            if fulltests:
+                tfSpec = freqanalysis(cfg, self.tfData)
+                assert 0.02 > tfSpec.freq.min() > 0
+                assert tfSpec.freq.max() == (self.tfData.samplerate / 2)
+                assert tfSpec.freq.size > 60
 
-            for tk, trlArr in enumerate(tfSpec.trials):
+            for tk, trlArr in enumerate(tfSpecFoi.trials):
 
                 # Get reference trial-number in input object
                 trlNo = tk
@@ -1238,17 +1283,19 @@ class TestSuperlet():
                     trlNo = select["trials"][tk]
 
                 # Ensure timing array was computed correctly and independent of `foi`/`foilim`
-                assert np.array_equal(timeArr, tfSpec.time[tk])
-                assert np.array_equal(tfSpec.time[tk], tfSpecFoi.time[tk])
+                assert np.array_equal(timeArr, tfSpecFoi.time[tk])
                 assert np.array_equal(tfSpecFoi.time[tk], tfSpecFoiLim.time[tk])
+                if fulltests:
+                    assert np.array_equal(timeArr, tfSpec.time[tk])
+                    assert np.array_equal(tfSpec.time[tk], tfSpecFoi.time[tk])
 
-                for chan in range(tfSpec.channel.size):
+                for chan in range(tfSpecFoi.channel.size):
 
                     # Get reference channel in input object to determine underlying modulator
                     chanNo = chan
                     if select:
                         if "toilim" not in select.keys():
-                            chanNo = np.where(self.tfData.channel == select["channels"][chan])[0][0]
+                            chanNo = np.where(self.tfData.channel == select["channel"][chan])[0][0]
                     if chanNo % 2:
                         modIdx = self.odd[(-1)**trlNo]
                     else:
@@ -1257,22 +1304,6 @@ class TestSuperlet():
                     modulator = self.modulators[timeSelection, modIdx]
                     modCounts = [sum(modulator == modulator.min()), sum(modulator == modulator.max())]
 
-                    # Be more lenient w/`tfSpec`: don't scan for min/max freq, but all peaks at once
-                    # (auto-scale resolution potentially too coarse to differentiate b/w min/max);
-                    # consider peak-count equal up to 2 misses
-                    Zxx = trlArr[tuple(tfIdx)].squeeze()
-                    ZxxMax = Zxx.max()
-                    ZxxThresh = 0.2 * ZxxMax
-                    _, freqPeaks = np.where(Zxx >= (ZxxMax - ZxxThresh))
-                    peakVals, peakCounts = np.unique(freqPeaks, return_counts=True)
-                    freqPeak = peakVals[peakCounts.argmax()]
-                    modCount = np.ceil(sum(modCounts) / 2)
-                    peakProfile = Zxx[:, freqPeak - 1 : freqPeak + 2].mean(axis=1)
-                    peaks, _ = scisig.find_peaks(peakProfile, height=2*ZxxThresh, distance=5)
-                    if np.abs(peaks.size - modCount) > 2:
-                        modCount = sum(modCounts)
-                    assert np.abs(peaks.size - modCount) <= 2
-
                     # Now for `tfSpecFoi`/`tfSpecFoiLim` on the other side be more
                     # stringent and really count maxima/minima (frequency values have
                     # been explicitly queried, must not be too coarse); that said,
@@ -1292,7 +1323,10 @@ class TestSuperlet():
                                 peaks, _ = scisig.find_peaks(peakProfile, prominence=0.75*height, height=height, distance=5)
                             assert np.abs(peaks.size - modCounts[fk]) <= 2
 
-    def test_slet_toi(self):
+                    # Be more lenient w/`tfSpec`: don't scan for min/max freq, but all peaks at once
+                    # (auto-scale resolution potentially too coarse to differentiate b/w min/max);
+
+    def test_slet_toi(self, fulltests):
         # Don't keep trials to speed things up a bit
         cfg = get_defaults(freqanalysis)
         cfg.method = "superlet"
@@ -1306,6 +1340,10 @@ class TestSuperlet():
                    np.arange(-15, -10, 1/self.tfData.samplerate),
                    np.arange(1, 20, 2)]
 
+        # Just pick one `toi` at random for quickly running tests
+        if not fulltests:
+            toiArrs = [random.choice(toiArrs)]
+
         # Combine `toi`-testing w/in-place data-pre-selection
         for select in self.dataSelections:
             cfg.select = select
@@ -1317,7 +1355,7 @@ class TestSuperlet():
 
         # Test correct time-array assembly for ``toi = "all"`` (cut down data signifcantly
         # to not overflow memory here)
-        cfg.select = {"trials": [0], "channels": [0], "toilim": [-0.5, 0.5]}
+        cfg.select = {"trials": [0], "channel": [0], "toilim": [-0.5, 0.5]}
         cfg.toi = "all"
         tfSpec = freqanalysis(cfg, self.tfData)
         dt = 1/self.tfData.samplerate
@@ -1337,7 +1375,7 @@ class TestSuperlet():
             freqanalysis(cfg, self.tfData)
             assert "Invalid value of `toi`: 'unsorted list/array'" in str(spyval.value)
 
-    def test_slet_irregular_trials(self):
+    def test_slet_irregular_trials(self, fulltests):
         # Set up wavelet to compute "full" TF spectrum for all time-points
         cfg = get_defaults(freqanalysis)
         cfg.method = "superlet"
@@ -1345,22 +1383,30 @@ class TestSuperlet():
         cfg.output = "pow"
         cfg.toi = "all"
 
+        # Reduce test-data size for quick test runs
+        if fulltests:
+            nTrials = 5
+            nChannels = 16
+        else:
+            nTrials = 2
+            nChannels = 2
+
         # start harmless: equidistant trials w/multiple tapers
-        artdata = generate_artificial_data(nTrials=5, nChannels=16,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            equidistant=True, inmemory=False)
         tfSpec = freqanalysis(artdata, **cfg)
         for tk, origTime in enumerate(artdata.time):
             assert np.array_equal(origTime, tfSpec.time[tk])
 
         # non-equidistant trials w/multiple tapers
-        artdata = generate_artificial_data(nTrials=5, nChannels=16,
+        artdata = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                            equidistant=False, inmemory=False)
         tfSpec = freqanalysis(artdata, **cfg)
         for tk, origTime in enumerate(artdata.time):
             assert np.array_equal(origTime, tfSpec.time[tk])
 
         # same + reversed dimensional order in input object
-        cfg.data = generate_artificial_data(nTrials=5, nChannels=16,
+        cfg.data = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
                                             equidistant=False, inmemory=False,
                                             dimord=AnalogData._defaultDimord[::-1])
         tfSpec = freqanalysis(cfg)
@@ -1368,23 +1414,23 @@ class TestSuperlet():
             assert np.array_equal(origTime, tfSpec.time[tk])
 
         # same + overlapping trials
-        cfg.data = generate_artificial_data(nTrials=5, nChannels=16,
-                                           equidistant=False, inmemory=False,
-                                           dimord=AnalogData._defaultDimord[::-1],
-                                           overlapping=True)
+        cfg.data = generate_artificial_data(nTrials=nTrials, nChannels=nChannels,
+                                            equidistant=False, inmemory=False,
+                                            dimord=AnalogData._defaultDimord[::-1],
+                                            overlapping=True)
         tfSpec = freqanalysis(cfg)
         for tk, origTime in enumerate(cfg.data.time):
             assert np.array_equal(origTime, tfSpec.time[tk])
 
     @skip_without_acme
     @skip_low_mem
-    def test_slet_parallel(self, testcluster):
+    def test_slet_parallel(self, testcluster, fulltests):
         # collect all tests of current class and repeat them running concurrently
         client = dd.Client(testcluster)
         all_tests = [attr for attr in self.__dir__()
-                     if (inspect.ismethod(getattr(self, attr)) and attr != "test_slet_parallel")]
+                     if (inspect.ismethod(getattr(self, attr)) and attr not in ["test_slet_parallel", "test_cut_slet_selections"])]
         for test in all_tests:
-            getattr(self, test)()
+            getattr(self, test)(fulltests)
             flush_local_cluster(testcluster)
 
         # now create uniform `cfg` for remaining SLURM tests
